Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(323)

Unified Diff: device/bluetooth/test/bluetooth_test_mac.h

Issue 2595373003: Bluetooth: mac: Working on macOS descriptor implementation. (Closed)
Patch Set: Fixes Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « device/bluetooth/bluetooth_remote_gatt_service_mac.mm ('k') | device/bluetooth/test/bluetooth_test_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/bluetooth/test/bluetooth_test_mac.h
diff --git a/device/bluetooth/test/bluetooth_test_mac.h b/device/bluetooth/test/bluetooth_test_mac.h
index 2aac8a931d1411ca0505cb685c82dd558a850ac4..90a7e89cf3a57a76788e5642172f6ea6d813ce6b 100644
--- a/device/bluetooth/test/bluetooth_test_mac.h
+++ b/device/bluetooth/test/bluetooth_test_mac.h
@@ -66,6 +66,8 @@ class BluetoothTestMac : public BluetoothTestBase {
void SimulateGattCharacteristicWriteError(
BluetoothRemoteGattCharacteristic* characteristic,
BluetoothRemoteGattService::GattErrorCode error_code) override;
+ void SimulateGattDescriptor(BluetoothRemoteGattCharacteristic* characteristic,
+ const std::string& uuid) override;
void SimulateGattNotifySessionStarted(
BluetoothRemoteGattCharacteristic* characteristic) override;
void SimulateGattNotifySessionStartError(
@@ -99,7 +101,10 @@ class BluetoothTestMac : public BluetoothTestBase {
// Returns MockCBPeripheral from BluetoothRemoteGattService.
MockCBPeripheral* GetMockCBPeripheral(
BluetoothRemoteGattService* service) const;
- // Returns MockCBPeripheral from BluetoothRemoteGattService.
+ // Returns MockCBPeripheral from BluetoothRemoteGattCharacteristic.
+ MockCBPeripheral* GetMockCBPeripheral(
+ BluetoothRemoteGattCharacteristic* characteristic) const;
+ // Returns MockCBCharacteristic from BluetoothRemoteGattCharacteristic.
MockCBCharacteristic* GetCBMockCharacteristic(
BluetoothRemoteGattCharacteristic* characteristic) const;
« no previous file with comments | « device/bluetooth/bluetooth_remote_gatt_service_mac.mm ('k') | device/bluetooth/test/bluetooth_test_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698